@@ -1,7 +1,7 @@
 ################################################################################
 # BSD LICENSE
 #
-# Copyright(c) 2019-2021 Intel Corporation. All rights reserved.
+# Copyright(c) 2019-2023 Intel Corporation. All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -30,16 +30,29 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ################################################################################
 
+"""
+Unit tests for appqos.power module
+"""
+
 import mock
 import pytest
 
-import power
-import power_common
-import sstbf
+from appqos import power
+from appqos import power_common
+from appqos import sstbf
+from appqos.config import Config
+
+try:
+    import pwr
+
+    HAS_PWR = True
+except ImportError:
+    HAS_PWR = False
 
 class TestRestPowerProfiles:
 
 
+    @pytest.mark.skipif(not HAS_PWR, reason="pwr package not installed")
     def test_is_sstcp_enabled(self):
         class SYS:
             def __init__(self, enabled):
@@ -63,6 +76,7 @@ class TestRestPowerProfiles:
             mock_get_system.assert_called_once()
 
 
+    @pytest.mark.skipif(not HAS_PWR, reason="pwr package not installed")
     def test__get_pwr_cpus(self):
         class CPU:
             def __init__(self, core_list):
@@ -90,6 +104,7 @@ class TestRestPowerProfiles:
             mock_get_cpus.assert_called_once()
 
 
+    @pytest.mark.skipif(not HAS_PWR, reason="pwr package not installed")
     def test__get_pwr_cores(self):
         class CORE:
             def __init__(self, id):
@@ -133,11 +148,11 @@ class TestRestPowerProfiles:
         assert -1 == power._set_freqs_epp(cores=[1,2,3], min_freq=None, max_freq=None, epp=None)
 
         for ret_val in [[], None]:
-            with mock.patch("power_common.get_pwr_cores", return_value=ret_val) as mock_get_cores:
+            with mock.patch("appqos.power_common.get_pwr_cores", return_value=ret_val) as mock_get_cores:
                 assert -1 == power._set_freqs_epp(cores=[1,2,3], min_freq=1000, max_freq=2300, epp="performance")
                 mock_get_cores.assert_called_once()
 
-        with mock.patch("power_common.get_pwr_cores", return_value=CORES_LIST) as mock_get_cores:
+        with mock.patch("appqos.power_common.get_pwr_cores", return_value=CORES_LIST) as mock_get_cores:
             assert 0 == power._set_freqs_epp(cores=[1,2,3], min_freq=1000, max_freq=2300, epp="performance")
             mock_get_cores.assert_called_once()
 
@@ -165,7 +180,7 @@ class TestRestPowerProfiles:
         for val in [[], None]:
             assert -1 == power.reset(val)
 
-        with mock.patch("power_common.get_pwr_cores", return_value=CORES_LIST) as mock_get_cores:
+        with mock.patch("appqos.power_common.get_pwr_cores", return_value=CORES_LIST) as mock_get_cores:
             assert 0 == power.reset([0, 1, 2])
             mock_get_cores.assert_called_once()
 
@@ -182,12 +197,12 @@ class TestRestPowerProfiles:
                 self.lowest_freq = freq
 
         for ret_val in [[], None]:
-            with mock.patch("power_common.get_pwr_cpus", return_value = ret_val) as mock_get_cpus:
+            with mock.patch("appqos.power_common.get_pwr_cpus", return_value = ret_val) as mock_get_cpus:
                 assert None == power_common.get_pwr_lowest_freq()
                 mock_get_cpus.assert_called_once()
 
         for freq in [1000, 1500, 2000]:
-            with mock.patch("power_common.get_pwr_cpus", return_value=[CPU(freq)]) as mock_get_cpus:
+            with mock.patch("appqos.power_common.get_pwr_cpus", return_value=[CPU(freq)]) as mock_get_cpus:
                 assert freq == power_common.get_pwr_lowest_freq()
                 mock_get_cpus.assert_called_once()
 
@@ -198,12 +213,12 @@ class TestRestPowerProfiles:
                 self.base_freq = freq
 
         for ret_val in [[], None]:
-            with mock.patch("power_common.get_pwr_cpus", return_value = ret_val) as mock_get_cpus:
+            with mock.patch("appqos.power_common.get_pwr_cpus", return_value = ret_val) as mock_get_cpus:
                 assert None == power_common.get_pwr_base_freq()
                 mock_get_cpus.assert_called_once()
 
         for freq in [2000, 2500, 3000]:
-            with mock.patch("power_common.get_pwr_cpus", return_value=[CPU(freq)]) as mock_get_cpus:
+            with mock.patch("appqos.power_common.get_pwr_cpus", return_value=[CPU(freq)]) as mock_get_cpus:
                 assert freq == power_common.get_pwr_base_freq()
                 mock_get_cpus.assert_called_once()
 
@@ -214,12 +229,12 @@ class TestRestPowerProfiles:
                 self.highest_freq = freq
 
         for ret_val in [[], None]:
-            with mock.patch("power_common.get_pwr_cpus", return_value = ret_val) as mock_get_cpus:
+            with mock.patch("appqos.power_common.get_pwr_cpus", return_value = ret_val) as mock_get_cpus:
                 assert None == power_common.get_pwr_highest_freq()
                 mock_get_cpus.assert_called_once()
 
         for freq in [3000, 3500, 4000]:
-            with mock.patch("power_common.get_pwr_cpus", return_value=[CPU(freq)]) as mock_get_cpus:
+            with mock.patch("appqos.power_common.get_pwr_cpus", return_value=[CPU(freq)]) as mock_get_cpus:
                 assert freq == power_common.get_pwr_highest_freq()
                 mock_get_cpus.assert_called_once()
 
@@ -227,17 +242,17 @@ class TestRestPowerProfiles:
     def test__is_min_freq_valid(self):
 
         for ret_val in [[], None]:
-            with mock.patch("power_common.get_pwr_lowest_freq", return_value = ret_val) as mock_get:
+            with mock.patch("appqos.power_common.get_pwr_lowest_freq", return_value = ret_val) as mock_get:
                 assert None == power._is_min_freq_valid(1000)
                 mock_get.assert_called_once()
 
         for freq in [500, 1000, 1499]:
-            with mock.patch("power_common.get_pwr_lowest_freq", return_value = 1500) as mock_get:
+            with mock.patch("appqos.power_common.get_pwr_lowest_freq", return_value = 1500) as mock_get:
                 assert False == power._is_min_freq_valid(freq)
                 mock_get.assert_called_once()
 
         for freq in [1000, 1500, 2000]:
-            with mock.patch("power_common.get_pwr_lowest_freq", return_value = 1000) as mock_get:
+            with mock.patch("appqos.power_common.get_pwr_lowest_freq", return_value = 1000) as mock_get:
                 assert True == power._is_min_freq_valid(freq)
                 mock_get.assert_called_once()
 
@@ -245,17 +260,17 @@ class TestRestPowerProfiles:
     def test__is_max_freq_valid(self):
 
         for ret_val in [[], None]:
-            with mock.patch("power_common.get_pwr_highest_freq", return_value = ret_val) as mock_get:
+            with mock.patch("appqos.power_common.get_pwr_highest_freq", return_value = ret_val) as mock_get:
                 assert None == power._is_max_freq_valid(1000)
                 mock_get.assert_called_once()
 
         for freq in [3501, 3750, 4000]:
-            with mock.patch("power_common.get_pwr_highest_freq", return_value = 3500) as mock_get:
+            with mock.patch("appqos.power_common.get_pwr_highest_freq", return_value = 3500) as mock_get:
                 assert False == power._is_max_freq_valid(freq)
                 mock_get.assert_called_once()
 
         for freq in [2000, 3000, 3500]:
-            with mock.patch("power_common.get_pwr_highest_freq", return_value = 3500) as mock_get:
+            with mock.patch("appqos.power_common.get_pwr_highest_freq", return_value = 3500) as mock_get:
                 assert True == power._is_max_freq_valid(freq)
                 mock_get.assert_called_once()
 
@@ -274,7 +289,7 @@ class TestRestPowerProfiles:
         for sstbf in [True, False]:
             result = not sstbf
 
-            with mock.patch('sstbf.is_sstbf_configured', return_value = sstbf):
+            with mock.patch('appqos.sstbf.is_sstbf_configured', return_value = sstbf):
                 assert result == power._do_admission_control_check()
 
 
@@ -299,11 +314,11 @@ class TestRestPowerProfiles:
             ]
         }
 
-        with mock.patch('power._is_max_freq_valid', return_value = True) as mock_is_max,\
-            mock.patch('power._is_min_freq_valid', return_value = True) as mock_is_min,\
-            mock.patch('power._is_epp_valid', return_value = True) as mock_is_epp,\
-            mock.patch('power._do_admission_control_check', return_value = True),\
-            mock.patch('power._admission_control_check', return_value = True) as mock_admission_control_check:
+        with mock.patch('appqos.power._is_max_freq_valid', return_value = True) as mock_is_max,\
+            mock.patch('appqos.power._is_min_freq_valid', return_value = True) as mock_is_min,\
+            mock.patch('appqos.power._is_epp_valid', return_value = True) as mock_is_epp,\
+            mock.patch('appqos.power._do_admission_control_check', return_value = True),\
+            mock.patch('appqos.power._admission_control_check', return_value = True) as mock_admission_control_check:
 
             with pytest.raises(ValueError, match="Power Profile 0, multiple profiles with same id."):
                 power.validate_power_profiles(data, True)
@@ -312,11 +327,11 @@ class TestRestPowerProfiles:
         # fix profile ID issue
         data['power_profiles'][-1]['id'] = 1
 
-        with mock.patch('power._is_max_freq_valid', return_value = True) as mock_is_max,\
-            mock.patch('power._is_min_freq_valid', return_value = True) as mock_is_min,\
-            mock.patch('power._is_epp_valid', return_value = True) as mock_is_epp,\
-            mock.patch('power._do_admission_control_check', return_value = True),\
-            mock.patch('power._admission_control_check', return_value = True) as mock__admission_control_check:
+        with mock.patch('appqos.power._is_max_freq_valid', return_value = True) as mock_is_max,\
+            mock.patch('appqos.power._is_min_freq_valid', return_value = True) as mock_is_min,\
+            mock.patch('appqos.power._is_epp_valid', return_value = True) as mock_is_epp,\
+            mock.patch('appqos.power._do_admission_control_check', return_value = True),\
+            mock.patch('appqos.power._admission_control_check', return_value = True) as mock__admission_control_check:
 
             power.validate_power_profiles(data, True)
 
@@ -332,21 +347,21 @@ class TestRestPowerProfiles:
             mock__admission_control_check.assert_called_once()
 
 
-        with mock.patch('power._is_max_freq_valid', return_value = True) as mock_is_max,\
-            mock.patch('power._is_min_freq_valid', return_value = True) as mock_is_min,\
-            mock.patch('power._is_epp_valid', return_value = True) as mock_is_epp,\
-            mock.patch('power._do_admission_control_check', return_value = False),\
-            mock.patch('power._admission_control_check') as mock__admission_control_check:
+        with mock.patch('appqos.power._is_max_freq_valid', return_value = True) as mock_is_max,\
+            mock.patch('appqos.power._is_min_freq_valid', return_value = True) as mock_is_min,\
+            mock.patch('appqos.power._is_epp_valid', return_value = True) as mock_is_epp,\
+            mock.patch('appqos.power._do_admission_control_check', return_value = False),\
+            mock.patch('appqos.power._admission_control_check') as mock__admission_control_check:
 
             power.validate_power_profiles(data, True)
             mock__admission_control_check.assert_not_called()
 
 
-        with mock.patch('power._is_max_freq_valid', return_value = True) as mock_is_max,\
-            mock.patch('power._is_min_freq_valid', return_value = True) as mock_is_min,\
-            mock.patch('power._is_epp_valid', return_value = True) as mock_is_epp,\
-            mock.patch('power._do_admission_control_check', return_value = True),\
-            mock.patch('power._admission_control_check') as mock__admission_control_check:
+        with mock.patch('appqos.power._is_max_freq_valid', return_value = True) as mock_is_max,\
+            mock.patch('appqos.power._is_min_freq_valid', return_value = True) as mock_is_min,\
+            mock.patch('appqos.power._is_epp_valid', return_value = True) as mock_is_epp,\
+            mock.patch('appqos.power._do_admission_control_check', return_value = True),\
+            mock.patch('appqos.power._admission_control_check') as mock__admission_control_check:
 
             power.validate_power_profiles(data, False)
             mock__admission_control_check.assert_not_called()
@@ -373,12 +388,12 @@ class TestRestPowerProfiles:
                         "cores": [4,5,6,7]
                     }]
         })
-        with mock.patch('power._is_max_freq_valid', return_value = True) as mock_is_max,\
-            mock.patch('power._is_min_freq_valid', return_value = True) as mock_is_min,\
-            mock.patch('power._is_epp_valid', return_value = True) as mock_is_epp,\
-            mock.patch('power._do_admission_control_check', return_value = True),\
-            mock.patch('power_common.get_pwr_cores', return_value=cores) as mock_get_cores,\
-            mock.patch('power_common.get_pwr_sys', return_value=sys) as mock_get_sys:
+        with mock.patch('appqos.power._is_max_freq_valid', return_value = True) as mock_is_max,\
+            mock.patch('appqos.power._is_min_freq_valid', return_value = True) as mock_is_min,\
+            mock.patch('appqos.power._is_epp_valid', return_value = True) as mock_is_epp,\
+            mock.patch('appqos.power._do_admission_control_check', return_value = True),\
+            mock.patch('appqos.power_common.get_pwr_cores', return_value=cores) as mock_get_cores,\
+            mock.patch('appqos.power_common.get_pwr_sys', return_value=sys) as mock_get_sys:
 
             power.validate_power_profiles(data, True)
             sys.request_config.assert_called_once()
@@ -392,12 +407,12 @@ class TestRestPowerProfiles:
 
         sys.request_config = mock.MagicMock(return_value=False)
         sys.refresh_all.reset_mock()
-        with mock.patch('power._is_max_freq_valid', return_value = True) as mock_is_max,\
-            mock.patch('power._is_min_freq_valid', return_value = True) as mock_is_min,\
-            mock.patch('power._is_epp_valid', return_value = True) as mock_is_epp,\
-            mock.patch('power._do_admission_control_check', return_value = True),\
-            mock.patch('power_common.get_pwr_cores', return_value=cores) as mock_get_cores,\
-            mock.patch('power_common.get_pwr_sys', return_value=sys) as mock_get_sys:
+        with mock.patch('appqos.power._is_max_freq_valid', return_value = True) as mock_is_max,\
+            mock.patch('appqos.power._is_min_freq_valid', return_value = True) as mock_is_min,\
+            mock.patch('appqos.power._is_epp_valid', return_value = True) as mock_is_epp,\
+            mock.patch('appqos.power._do_admission_control_check', return_value = True),\
+            mock.patch('appqos.power_common.get_pwr_cores', return_value=cores) as mock_get_cores,\
+            mock.patch('appqos.power_common.get_pwr_sys', return_value=sys) as mock_get_sys:
 
             with pytest.raises(power.AdmissionControlError, match="Power Profiles configuration would cause CPU to be oversubscribed."):
                 power.validate_power_profiles(data, True)
@@ -405,33 +420,33 @@ class TestRestPowerProfiles:
             sys.refresh_all.assert_called_once()
 
 
-        with mock.patch('power._is_max_freq_valid',  return_value = False ) as mock_is_max,\
-            mock.patch('power._is_min_freq_valid',  return_value = True) as mock_is_min,\
-            mock.patch('power._is_epp_valid', return_value = True) as mock_is_epp,\
-            mock.patch('power._do_admission_control_check', return_value = True),\
-            mock.patch('power._admission_control_check', return_value = True) as mock__admission_control_check:
+        with mock.patch('appqos.power._is_max_freq_valid',  return_value = False ) as mock_is_max,\
+            mock.patch('appqos.power._is_min_freq_valid',  return_value = True) as mock_is_min,\
+            mock.patch('appqos.power._is_epp_valid', return_value = True) as mock_is_epp,\
+            mock.patch('appqos.power._do_admission_control_check', return_value = True),\
+            mock.patch('appqos.power._admission_control_check', return_value = True) as mock__admission_control_check:
 
             with pytest.raises(ValueError, match="Power Profile 0, Invalid max. freq 2500."):
                 power.validate_power_profiles(data, True)
             mock__admission_control_check.assert_not_called()
 
 
-        with mock.patch('power._is_max_freq_valid',  return_value = True ) as mock_is_max,\
-            mock.patch('power._is_min_freq_valid',  return_value = False) as mock_is_min,\
-            mock.patch('power._is_epp_valid', return_value = True) as mock_is_epp,\
-            mock.patch('power._do_admission_control_check', return_value = True),\
-            mock.patch('power._admission_control_check', return_value = True) as mock__admission_control_check:
+        with mock.patch('appqos.power._is_max_freq_valid',  return_value = True ) as mock_is_max,\
+            mock.patch('appqos.power._is_min_freq_valid',  return_value = False) as mock_is_min,\
+            mock.patch('appqos.power._is_epp_valid', return_value = True) as mock_is_epp,\
+            mock.patch('appqos.power._do_admission_control_check', return_value = True),\
+            mock.patch('appqos.power._admission_control_check', return_value = True) as mock__admission_control_check:
 
             with pytest.raises(ValueError, match="Power Profile 0, Invalid min. freq 1500."):
                 power.validate_power_profiles(data, True)
             mock__admission_control_check.assert_not_called()
 
 
-        with mock.patch('power._is_max_freq_valid',  return_value = True ) as mock_is_max,\
-            mock.patch('power._is_min_freq_valid',  return_value = True) as mock_is_min,\
-            mock.patch('power._is_epp_valid', return_value = False) as mock_is_epp,\
-            mock.patch('power._do_admission_control_check', return_value = True),\
-            mock.patch('power._admission_control_check', return_value = True) as mock__admission_control_check:
+        with mock.patch('appqos.power._is_max_freq_valid',  return_value = True ) as mock_is_max,\
+            mock.patch('appqos.power._is_min_freq_valid',  return_value = True) as mock_is_min,\
+            mock.patch('appqos.power._is_epp_valid', return_value = False) as mock_is_epp,\
+            mock.patch('appqos.power._do_admission_control_check', return_value = True),\
+            mock.patch('appqos.power._admission_control_check', return_value = True) as mock__admission_control_check:
 
             with pytest.raises(ValueError, match="Power Profile 0, Invalid EPP value performance."):
                 power.validate_power_profiles(data, True)
@@ -441,11 +456,11 @@ class TestRestPowerProfiles:
         # set invalid min. freq, higher than max. freq
         data['power_profiles'][-1]['min_freq'] = data['power_profiles'][-1]['max_freq'] + 1
 
-        with mock.patch('power._is_max_freq_valid',  return_value = True) as mock_is_max,\
-            mock.patch('power._is_min_freq_valid',  return_value = True) as mock_is_min,\
-            mock.patch('power._is_epp_valid', return_value = True) as mock_is_epp,\
-            mock.patch('power._do_admission_control_check', return_value = True),\
-            mock.patch('power._admission_control_check', return_value = True) as mock__admission_control_check:
+        with mock.patch('appqos.power._is_max_freq_valid',  return_value = True) as mock_is_max,\
+            mock.patch('appqos.power._is_min_freq_valid',  return_value = True) as mock_is_min,\
+            mock.patch('appqos.power._is_epp_valid', return_value = True) as mock_is_epp,\
+            mock.patch('appqos.power._do_admission_control_check', return_value = True),\
+            mock.patch('appqos.power._admission_control_check', return_value = True) as mock__admission_control_check:
 
             with pytest.raises(ValueError, match="Power Profile 1, Invalid freqs! min. freq is higher than max. freq."):
                 power.validate_power_profiles(data, True)
@@ -461,7 +476,7 @@ class TestRestPowerProfiles:
         profiles = {5: {"min_freq": 1500, "max_freq": 2500, "epp": "performance", "id": 5},
             6 : {"min_freq": 1000, "max_freq": 1200, "epp": "power", "id": 6}}
 
-        def get_pool_attr(attr, pool_id):
+        def get_pool_attr(cls, attr, pool_id):
             if attr == 'id':
                 if pool_id is None:
                     return pool_ids
@@ -477,17 +492,17 @@ class TestRestPowerProfiles:
 
             return None
 
-        def get_power_profile(id):
+        def get_power_profile(cls, id):
             return profiles[id]
 
         # ERROR POWER: No Pools configured...
         power.PREV_PROFILES.clear()
-        with mock.patch('common.CONFIG_STORE.get_pool_attr', return_value=None) as mock_get_pool_attr,\
-            mock.patch('common.CONFIG_STORE.get_power_profile') as mock_get_power_profile,\
-            mock.patch('power.reset') as mock_reset,\
-            mock.patch('power._set_freqs_epp') as mock_set_freqs_epp:
+        with mock.patch('appqos.config.Config.get_pool_attr', return_value=None) as mock_get_pool_attr,\
+            mock.patch('appqos.config.Config.get_power_profile') as mock_get_power_profile,\
+            mock.patch('appqos.power.reset') as mock_reset,\
+            mock.patch('appqos.power._set_freqs_epp') as mock_set_freqs_epp:
 
-            assert -1 == power.configure_power()
+            assert -1 == power.configure_power(Config({}))
             mock_get_pool_attr.assert_called_once_with('id', None)
             mock_get_power_profile.assert_not_called()
             mock_reset.assert_not_called()
@@ -495,24 +510,24 @@ class TestRestPowerProfiles:
 
         # ERROR POWER: Profile 5 does not exist!
         power.PREV_PROFILES.clear()
-        with mock.patch('common.CONFIG_STORE.get_pool_attr', new=get_pool_attr),\
-            mock.patch('common.CONFIG_STORE.get_power_profile', return_value=None) as mock_get_power_profile,\
-            mock.patch('power.reset') as mock_reset,\
-            mock.patch('power._set_freqs_epp') as mock_set_freqs_epp:
+        with mock.patch('appqos.config.Config.get_pool_attr', new=get_pool_attr),\
+            mock.patch('appqos.config.Config.get_power_profile', return_value=None) as mock_get_power_profile,\
+            mock.patch('appqos.power.reset') as mock_reset,\
+            mock.patch('appqos.power._set_freqs_epp') as mock_set_freqs_epp:
 
-            assert -1 == power.configure_power()
+            assert -1 == power.configure_power(Config({}))
             mock_get_power_profile.assert_called_once_with(5)
             mock_reset.assert_not_called()
             mock_set_freqs_epp.assert_not_called()
 
         # All OK!
         power.PREV_PROFILES.clear()
-        with mock.patch('common.CONFIG_STORE.get_pool_attr', new=get_pool_attr),\
-            mock.patch('common.CONFIG_STORE.get_power_profile', new=get_power_profile),\
-            mock.patch('power.reset') as mock_reset,\
-            mock.patch('power._set_freqs_epp') as mock_set_freqs_epp:
+        with mock.patch('appqos.config.Config.get_pool_attr', new=get_pool_attr),\
+             mock.patch('appqos.config.Config.get_power_profile', new=get_power_profile),\
+             mock.patch('appqos.power.reset') as mock_reset,\
+             mock.patch('appqos.power._set_freqs_epp') as mock_set_freqs_epp:
 
-            assert 0 == power.configure_power()
+            assert 0 == power.configure_power(Config({}))
             mock_reset.assert_not_called()
             mock_set_freqs_epp.assert_any_call(pool_to_cores[0], profiles[5]["min_freq"], profiles[5]["max_freq"], profiles[5]["epp"])
             mock_set_freqs_epp.assert_any_call(pool_to_cores[1], profiles[6]["min_freq"], profiles[6]["max_freq"], profiles[6]["epp"])
@@ -520,23 +535,23 @@ class TestRestPowerProfiles:
         # POWER: Skipping Pool 0, no cores assigned
         power.PREV_PROFILES.clear()
         pool_to_cores[0] = []
-        with mock.patch('common.CONFIG_STORE.get_pool_attr', new=get_pool_attr),\
-            mock.patch('common.CONFIG_STORE.get_power_profile', new=get_power_profile),\
-            mock.patch('power.reset') as mock_reset,\
-            mock.patch('power._set_freqs_epp') as mock_set_freqs_epp:
+        with mock.patch('appqos.config.Config.get_pool_attr', new=get_pool_attr),\
+            mock.patch('appqos.config.Config.get_power_profile', new=get_power_profile),\
+            mock.patch('appqos.power.reset') as mock_reset,\
+            mock.patch('appqos.power._set_freqs_epp') as mock_set_freqs_epp:
 
-            assert 0 == power.configure_power()
+            assert 0 == power.configure_power(Config({}))
             mock_reset.assert_not_called()
             mock_set_freqs_epp.assert_called_once_with(pool_to_cores[1], profiles[6]["min_freq"], profiles[6]["max_freq"], profiles[6]["epp"])
 
         # POWER: Pool 1, no power profile assigned. Resetting to defaults.
         power.PREV_PROFILES.clear()
         pool_to_profiles[1] = None
-        with mock.patch('common.CONFIG_STORE.get_pool_attr', new=get_pool_attr),\
-            mock.patch('common.CONFIG_STORE.get_power_profile', new=get_power_profile),\
-            mock.patch('power.reset') as mock_reset,\
-            mock.patch('power._set_freqs_epp') as mock_set_freqs_epp:
+        with mock.patch('appqos.config.Config.get_pool_attr', new=get_pool_attr),\
+            mock.patch('appqos.config.Config.get_power_profile', new=get_power_profile),\
+            mock.patch('appqos.power.reset') as mock_reset,\
+            mock.patch('appqos.power._set_freqs_epp') as mock_set_freqs_epp:
 
-            assert 0 == power.configure_power()
+            assert 0 == power.configure_power(Config({}))
             mock_reset.assert_called_once_with(pool_to_cores[1])
             mock_set_freqs_epp.assert_not_called()
