@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2014-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2014-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -36,15 +36,16 @@
  *
  */
 
+#include "pqos.h"
+
+#include <ctype.h>
+#include <fcntl.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
-#include <ctype.h>
-#include <sys/types.h>
 #include <sys/stat.h>
-#include <fcntl.h>
-#include "pqos.h"
+#include <sys/types.h>
+#include <unistd.h>
 
 /**
  * @brief Prints information about cache allocation settings in the system
@@ -143,8 +144,7 @@ main(int argc, char *argv[])
                 goto error_exit;
         }
         /* Reset Api */
-        ret = pqos_alloc_reset(PQOS_REQUIRE_CDP_ANY, PQOS_REQUIRE_CDP_ANY,
-                               PQOS_MBA_ANY);
+        ret = pqos_alloc_reset_config(NULL);
         if (ret != PQOS_RETVAL_OK)
                 printf("CAT reset failed!\n");
         else
