@@ -39,6 +39,7 @@
 
 #include "allocation.h"
 #include "cap.h"
+#include "common.h"
 #include "cpu_registers.h"
 #include "log.h"
 #include "machine.h"
@@ -452,6 +453,11 @@ cpuinfo_build_topo(struct apic_info *apic)
                 return NULL;
         }
 
+        if (pqos_set_no_files_limit(max_core_count)) {
+                LOG_ERROR("Open files limit not sufficient!\n");
+                return NULL;
+        }
+
         const size_t mem_sz =
             sizeof(*l_cpu) + (max_core_count * sizeof(struct pqos_coreinfo));
 
@@ -578,6 +584,7 @@ init_config(struct cpuinfo_config *config, enum pqos_vendor vendor)
                 config->mba_max = PQOS_MBA_MAX_AMD;
                 config->mba_msr_reg = PQOS_MSR_MBA_MASK_START_AMD;
                 config->mba_default_val = PQOS_MBA_MAX_AMD;
+                config->smba_msr_reg = PQOS_MSR_SMBA_MASK_START_AMD;
         } else {
                 LOG_ERROR("init_config: init failed!");
                 return -EFAULT;
@@ -645,6 +652,7 @@ cpuinfo_init(enum pqos_interface interface, struct pqos_cpuinfo **topology)
                 if (vendor == PQOS_VENDOR_AMD) {
                         info->l3cat_id = info->l3_id;
                         info->mba_id = info->l3_id;
+                        info->smba_id = info->l3_id;
                 } else {
                         info->l3cat_id = info->socket;
                         info->mba_id = info->socket;
