@@ -45,9 +45,10 @@
 int
 monitor_utils_uinttostr(char *buf, const int buf_len, const unsigned val)
 {
-        ASSERT(buf != NULL);
         int ret;
 
+        ASSERT(buf != NULL);
+
         memset(buf, 0, buf_len);
         ret = snprintf(buf, buf_len, "%u", val);
 
@@ -58,6 +59,23 @@ monitor_utils_uinttostr(char *buf, const int buf_len, const unsigned val)
         return ret;
 }
 
+int
+monitor_utils_uinttohexstr(char *buf, const int buf_len, const unsigned val)
+{
+        int ret;
+
+        ASSERT(buf != NULL);
+
+        memset(buf, 0, buf_len);
+        ret = snprintf(buf, buf_len, "0x%x", val);
+
+        /* Return -1 when output was truncated */
+        if (ret >= buf_len)
+                ret = -1;
+
+        return ret;
+}
+
 /**
  * @brief Scale byte value up to KB
  *
