@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2018-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2018-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -33,26 +33,26 @@
 #define _GNU_SOURCE
 #include <ctype.h>
 #include <errno.h>
+#include <getopt.h>
 #include <limits.h>
+#include <pthread.h>
+#include <signal.h>
+#include <stdarg.h>
+#include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdint.h>
-#include <stdarg.h>
 #include <string.h>
-#include <unistd.h>
-#include <signal.h>
 #include <sys/time.h>
-#include <pthread.h>
-#include <getopt.h>
+#include <unistd.h>
 
 #ifdef __linux__
-#include <sched.h>
 #include <cpuid.h>
+#include <sched.h>
 #endif
 
 #ifdef __FreeBSD__
-#include <sys/param.h>
 #include <sys/cpuset.h>
+#include <sys/param.h>
 #endif
 
 /**
@@ -60,12 +60,11 @@
  */
 
 #ifdef __linux__
-#define PAGE_SIZE (4 * 1024)
+#define PAGE_SIZE (4LLU * 1024)
 #endif
 
-#define MEMCHUNK_SIZE (PAGE_SIZE * 32 * 1024) /* 128MB chunk */
-#define CL_SIZE       (64)
-#define CHUNKS        (128)
+#define CL_SIZE (64LLU)
+#define CHUNKS  (256LLU)
 
 #ifdef DEBUG
 #include <assert.h>
@@ -137,6 +136,7 @@ static struct cpuid_out cpuid_7_0; /* leaf 7, sub-leaf 0 */
 static int stop_loop = 0;
 static void *memchunk = NULL;
 static unsigned memchunk_offset = 0;
+static size_t memchunk_size = PAGE_SIZE * 128 * 1024;
 
 /**
  * UTILS
@@ -185,6 +185,68 @@ lcpuid(const unsigned leaf, const unsigned subleaf, struct cpuid_out *out)
 #endif
 }
 
+/**
+ * @brief Obtain cache size
+ *
+ * @param [in] level cache level
+ * @param [out] size cache size
+ *
+ * @return operational status
+ * @retval -1 on error
+ */
+static int
+cpu_cache_size(const unsigned level, size_t *size)
+{
+        unsigned leaf;
+        unsigned subleaf = 0;
+
+        /* Check CPU vendor */
+        {
+                struct cpuid_out vendor;
+
+                lcpuid(0x0, 0x0, &vendor);
+
+                if (vendor.ebx == 0x756e6547 && vendor.edx == 0x49656e69 &&
+                    vendor.ecx == 0x6c65746e) {
+                        /* CPU vendor - Intel */
+                        leaf = 4;
+
+                } else if (vendor.ebx == 0x68747541 &&
+                           vendor.edx == 0x69746E65 &&
+                           vendor.ecx == 0x444D4163) {
+                        /* CPU vendor - AMD */
+                        leaf = 0x8000001D;
+                } else
+                        return -1;
+        }
+
+        for (subleaf = 0;; subleaf++) {
+                struct cpuid_out cache_info;
+                unsigned cache_level;
+                unsigned cache_type;
+
+                lcpuid(leaf, subleaf, &cache_info);
+                cache_type = cache_info.eax & 0x1f;        /* EAX bits 04:00 */
+                cache_level = (cache_info.eax >> 5) & 0x7; /* EAX bits 07:05 */
+
+                if (cache_type == 0 || cache_type >= 4)
+                        break; /* no more caches or reserved */
+                if (cache_level != level)
+                        continue;
+
+                unsigned num_ways = (cache_info.ebx >> 22) + 1;
+                unsigned num_sets = cache_info.ecx + 1;
+                unsigned line_size = (cache_info.ebx & 0xfff) + 1;
+                unsigned num_partitions = ((cache_info.ebx >> 12) & 0x3ff) + 1;
+                unsigned way_size = num_partitions * num_sets * line_size;
+
+                *size = way_size * num_ways;
+                return 0;
+        }
+
+        return -1;
+}
+
 static uint32_t
 detect_sse42(void)
 {
@@ -329,6 +391,16 @@ mem_flush(void *p, size_t s)
         sb();
 }
 
+ALWAYS_INLINE uint64_t
+get_value(void)
+{
+        static uint64_t val = 0;
+
+        val -= 57;
+
+        return val;
+}
+
 /**
  * @brief Function to initialize and allocate memory to thread
  *
@@ -346,7 +418,7 @@ malloc_and_init_memory(size_t s)
 
         if (ret != 0 || p == NULL) {
                 printf("ERROR: Failed to allocate %lu bytes\n",
-                       (unsigned long)s - s % PAGE_SIZE);
+                       (unsigned long)(s - s % PAGE_SIZE));
                 stop_loop = 1;
                 return NULL;
         }
@@ -355,12 +427,12 @@ malloc_and_init_memory(size_t s)
         size_t s64 = s / sizeof(uint64_t);
 
         while (s64 > 0) {
-                *p64 = (uint64_t)rand();
-                p64 += (CL_SIZE / sizeof(uint64_t));
-                s64 -= (CL_SIZE / sizeof(uint64_t));
+                *p64 = get_value();
+                ++p64;
+                --s64;
         }
 
-        mem_flush(p, MEMCHUNK_SIZE);
+        mem_flush(p, s);
         return p;
 }
 
@@ -760,15 +832,12 @@ cl_read_dqa(void *p)
 ALWAYS_INLINE void
 mem_execute(const unsigned bw, const enum cl_type type)
 {
-        const uint64_t val = (uint64_t)rand();
+        uint64_t val = get_value();
         char *cp = (char *)memchunk;
-        unsigned i = 0;
-        const size_t s = MEMCHUNK_SIZE / CL_SIZE; /* mem size in cache lines */
-
-        assert(memchunk != NULL);
+        unsigned i;
 
         for (i = 0; i < bw; i++) {
-                char *ptr = cp + (memchunk_offset * CL_SIZE);
+                char *ptr = cp + memchunk_offset;
 
                 switch (type) {
                 case CL_TYPE_PREFETCH_T0:
@@ -844,7 +913,8 @@ mem_execute(const unsigned bw, const enum cl_type type)
                         assert(0);
                         break;
                 }
-                if (++memchunk_offset >= s)
+                memchunk_offset += CL_SIZE;
+                if (memchunk_offset >= memchunk_size)
                         memchunk_offset = 0;
         }
         sb();
@@ -983,6 +1053,7 @@ main(int argc, char **argv)
         int option_index;
         int ret;
         uint64_t features;
+        size_t cache_size;
 
         /* clang-format off */
         struct option options[] = {
@@ -1079,6 +1150,8 @@ main(int argc, char **argv)
                 return EXIT_FAILURE;
         }
 
+        if (cpu_cache_size(3, &cache_size) == 0)
+                memchunk_size = (cache_size / PAGE_SIZE + 1) * PAGE_SIZE * 2;
         features = cpu_feature_detect();
 
         switch (type) {
@@ -1123,20 +1196,21 @@ main(int argc, char **argv)
                 break;
         }
 
-        printf("- THREAD logical core id: %u, "
-               " memory bandwidth [MB]: %u, starting...\n",
-               cpu, mem_bw);
-
         /* Bind thread to cpu */
         set_thread_affinity(cpu);
 
         /* Allocate memory */
-        memchunk = malloc_and_init_memory(MEMCHUNK_SIZE);
+        memchunk = malloc_and_init_memory(memchunk_size);
         if (memchunk == NULL) {
                 printf("Failed to allocate memory!\n");
                 return EXIT_FAILURE;
         }
 
+        printf("- THREAD logical core id: %u, "
+               " memory bandwidth [MB]: %u, starting...\n",
+               cpu, mem_bw);
+        fflush(stdout);
+
         /* Calculate memory bandwidth to use */
         mem_bw *= (((1024 * 1024) / CL_SIZE)) / CHUNKS;
 
