@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2020-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2020-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -30,17 +30,9 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <string.h>
-#include <stdlib.h>
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
-#include <cmocka.h>
-
-#include "test.h"
-#include "mock_machine.h"
-
 #include "allocation.h"
+#include "mock_machine.h"
+#include "test.h"
 
 /* ======== hw_alloc_reset_cos ======== */
 
@@ -76,4 +68,4 @@ main(void)
         result += cmocka_run_group_tests(tests, test_init_l3ca, test_fini);
 
         return result;
-}
\ No newline at end of file
+}
