@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2020-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2020-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -30,19 +30,11 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <string.h>
-#include <stdlib.h>
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
-#include <cmocka.h>
-
-#include "test.h"
+#include "allocation.h"
+#include "cpu_registers.h"
 #include "mock_cap.h"
 #include "mock_machine.h"
-
-#include "cpu_registers.h"
-#include "allocation.h"
+#include "test.h"
 
 /* ======== hw_alloc_reset_l2cdp ======== */
 
@@ -57,7 +49,8 @@ test_hw_alloc_reset_l2cdp_enable(void **state)
 
         data->cap_l2ca.cdp_on = 0;
 
-        will_return(__wrap__pqos_cap_get, data->cpu);
+        will_return_maybe(__wrap__pqos_get_cap, data->cap);
+        will_return_maybe(__wrap__pqos_get_cpu, data->cpu);
 
         l2cat_ids = pqos_cpu_get_l2ids(data->cpu, &l2cat_id_num);
         for (i = 0; i < l2cat_id_num; i++) {
@@ -67,14 +60,14 @@ test_hw_alloc_reset_l2cdp_enable(void **state)
 
                 expect_value(__wrap_msr_read, lcore, lcore);
                 expect_value(__wrap_msr_read, reg, PQOS_MSR_L2_QOS_CFG);
-                will_return(__wrap_msr_read, 0);
                 will_return(__wrap_msr_read, PQOS_RETVAL_OK);
+                will_return(__wrap_msr_read, 0);
 
                 expect_value(__wrap_msr_write, lcore, lcore);
                 expect_value(__wrap_msr_write, reg, PQOS_MSR_L2_QOS_CFG);
+                will_return(__wrap_msr_write, PQOS_RETVAL_OK);
                 expect_value(__wrap_msr_write, value,
                              PQOS_MSR_L2_QOS_CFG_CDP_EN);
-                will_return(__wrap_msr_write, PQOS_RETVAL_OK);
         }
 
         ret = hw_alloc_reset_l2cdp(l2cat_id_num, l2cat_ids, 1);
@@ -95,7 +88,8 @@ test_hw_alloc_reset_l2cdp_disable(void **state)
 
         data->cap_l2ca.cdp_on = 1;
 
-        will_return(__wrap__pqos_cap_get, data->cpu);
+        will_return_maybe(__wrap__pqos_get_cap, data->cap);
+        will_return_maybe(__wrap__pqos_get_cpu, data->cpu);
 
         l2cat_ids = pqos_cpu_get_l2ids(data->cpu, &l2cat_id_num);
         for (i = 0; i < l2cat_id_num; i++) {
@@ -105,8 +99,8 @@ test_hw_alloc_reset_l2cdp_disable(void **state)
 
                 expect_value(__wrap_msr_read, lcore, lcore);
                 expect_value(__wrap_msr_read, reg, PQOS_MSR_L2_QOS_CFG);
-                will_return(__wrap_msr_read, UINT64_MAX);
                 will_return(__wrap_msr_read, PQOS_RETVAL_OK);
+                will_return(__wrap_msr_read, UINT64_MAX);
 
                 expect_value(__wrap_msr_write, lcore, lcore);
                 expect_value(__wrap_msr_write, reg, PQOS_MSR_L2_QOS_CFG);
@@ -132,13 +126,13 @@ test_hw_alloc_reset_l2cdp_error_read(void **state __attribute__((unused)))
 
         data->cap_l2ca.cdp_on = 1;
 
-        will_return(__wrap__pqos_cap_get, data->cpu);
+        will_return_maybe(__wrap__pqos_get_cap, data->cap);
+        will_return_maybe(__wrap__pqos_get_cpu, data->cpu);
 
         l2cat_ids = pqos_cpu_get_l2ids(data->cpu, &l2cat_id_num);
 
         expect_value(__wrap_msr_read, lcore, 0);
         expect_value(__wrap_msr_read, reg, PQOS_MSR_L2_QOS_CFG);
-        will_return(__wrap_msr_read, UINT64_MAX);
         will_return(__wrap_msr_read, PQOS_RETVAL_ERROR);
 
         ret = hw_alloc_reset_l2cdp(l2cat_id_num, l2cat_ids, 0);
@@ -158,14 +152,15 @@ test_hw_alloc_reset_l2cdp_error_write(void **state __attribute__((unused)))
 
         data->cap_l2ca.cdp_on = 1;
 
-        will_return(__wrap__pqos_cap_get, data->cpu);
+        will_return_maybe(__wrap__pqos_get_cap, data->cap);
+        will_return_maybe(__wrap__pqos_get_cpu, data->cpu);
 
         l2cat_ids = pqos_cpu_get_l2ids(data->cpu, &l2cat_id_num);
 
         expect_value(__wrap_msr_read, lcore, 0);
         expect_value(__wrap_msr_read, reg, PQOS_MSR_L2_QOS_CFG);
-        will_return(__wrap_msr_read, 0);
         will_return(__wrap_msr_read, PQOS_RETVAL_OK);
+        will_return(__wrap_msr_read, 0);
 
         expect_value(__wrap_msr_write, lcore, 0);
         expect_value(__wrap_msr_write, reg, PQOS_MSR_L2_QOS_CFG);
@@ -189,7 +184,8 @@ test_hw_alloc_reset_l2cdp_error_param(void **state __attribute__((unused)))
 
         data->cap_l2ca.cdp_on = 1;
 
-        will_return(__wrap__pqos_cap_get, data->cpu);
+        will_return_maybe(__wrap__pqos_get_cap, data->cap);
+        will_return_maybe(__wrap__pqos_get_cpu, data->cpu);
 
         ret = hw_alloc_reset_l2cdp(l2cat_id_num, l2cat_ids, 0);
         assert_int_equal(ret, PQOS_RETVAL_ERROR);
@@ -210,4 +206,4 @@ main(void)
         result += cmocka_run_group_tests(tests, test_init_l2ca, test_fini);
 
         return result;
-}
\ No newline at end of file
+}
