@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2020-2022 Intel Corporation. All rights reserved.
+ * Copyright(c) 2020-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -35,6 +35,61 @@
 #include "mock_test.h"
 #include "pqos.h"
 
+#include <string.h>
+
+FILE *
+__wrap_pqos_fopen(const char *name, const char *mode)
+{
+        check_expected(name);
+        check_expected(mode);
+
+        if (strcmp(mode, "r") == 0) {
+                const char *data = mock_ptr_type(const char *);
+
+                if (data == NULL)
+                        return NULL;
+                else {
+                        FILE *fd = tmpfile();
+
+                        assert_non_null(fd);
+
+                        fprintf(fd, "%s", data);
+                        fseek(fd, 0, SEEK_SET);
+
+                        return fd;
+                }
+        }
+
+        return mock_ptr_type(FILE *);
+}
+
+int
+__wrap_pqos_fclose(FILE *fd)
+{
+        function_called();
+        assert_non_null(fd);
+
+        if (fd != NULL && fd != (FILE *)0xDEAD)
+                fclose(fd);
+
+        return mock_type(int);
+}
+
+int
+__wrap_pqos_fread_uint(const char *path, unsigned *value)
+{
+        int ret;
+
+        check_expected(path);
+        assert_non_null(value);
+
+        ret = mock_type(int);
+        if (ret == PQOS_RETVAL_OK)
+                *value = mock_type(unsigned);
+
+        return ret;
+}
+
 int
 __wrap_pqos_fread_uint64(const char *fname, unsigned base, uint64_t *value)
 {
@@ -81,3 +136,24 @@ __wrap_pqos_file_contains(const char *fname, const char *str, int *found)
 
         return ret;
 }
+
+size_t
+__wrap_fread(void *ptr, size_t size, size_t nmemb, FILE *stream)
+{
+        char *data;
+        size_t ret;
+
+        assert_int_equal(nmemb, 1);
+        assert_non_null(ptr);
+        assert_non_null(stream);
+
+        data = mock_ptr_type(char *);
+        ret = strlen(data);
+
+        if (ret > 0) {
+                assert_true(size >= strlen(data));
+                strncpy(ptr, data, size);
+        }
+
+        return ret;
+}
