@@ -1,7 +1,7 @@
 /*
  * BSD LICENSE
  *
- * Copyright(c) 2020-2021 Intel Corporation. All rights reserved.
+ * Copyright(c) 2020-2023 Intel Corporation. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -35,6 +35,8 @@
 
 #include "pqos.h"
 
+int __wrap_os_alloc_init(const struct pqos_cpuinfo *cpu,
+                         const struct pqos_cap *cap);
 int __wrap_os_alloc_assoc_set(const unsigned lcore, const unsigned class_id);
 int __wrap_os_alloc_assoc_get(const unsigned lcore, unsigned *class_id);
 int __wrap_os_alloc_assoc_set_pid(const pid_t task, const unsigned class_id);
@@ -51,9 +53,7 @@ int __wrap_os_alloc_assign_pid(const unsigned technology,
                                unsigned *class_id);
 int __wrap_os_alloc_release_pid(const pid_t *task_array,
                                 const unsigned task_num);
-int __wrap_os_alloc_reset(const enum pqos_cdp_config l3_cdp_cfg,
-                          const enum pqos_cdp_config l2_cdp_cfg,
-                          const enum pqos_mba_config mba_cfg);
+int __wrap_os_alloc_reset(const struct pqos_alloc_config *cfg);
 unsigned *__wrap_os_pid_get_pid_assoc(const unsigned class_id, unsigned *count);
 int __wrap_os_l3ca_set(const unsigned l3cat_id,
                        const unsigned num_cos,
